==> yamlfixer_opt_nc-0.4.0-py3-none-any.whl: yamlfixer/__main__.py <==
# -*- coding: utf-8 -*-
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#

"""Execute yamlfixer from the command line."""

import sys
import argparse

from . import __version__, __copyright__
from .yamlfixer import YAMLFixer

GPLBLURB = """
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

def run():
    """Main function."""
    # Ensure we read from stdin in case it's redirected
    if ("-" not in sys.argv[1:]) and not sys.stdin.isatty():
        sys.argv.append("-")

    # Parse the command line arguments
    cmdline = argparse.ArgumentParser(description="Fix formatting problems in YAML documents. "
                                      "If no file is specified,\nthen reads input from `stdin`.",
                                      epilog=f"{__copyright__}\n{GPLBLURB}",
                                      formatter_class=argparse.RawDescriptionHelpFormatter)
    cmdline.add_argument("-v", "--version",
                         action="version",
                         version=f"yamlfixer v{__version__}",
                         help="display this program's version number and exit.")
    cmdline.add_argument("-b", "--backup",
                         action="store_true",
                         help="make a backup copy of original files as `.orig`")
    cmdline.add_argument("-d", "--debug",
                         action="store_true",
                         help="output debug information to stderr.")
    cmdline.add_argument("-l", "--listfixes",
                         action="store_true",
                         help="output the list of available fixes.")
    mutuallyexclusive = cmdline.add_mutually_exclusive_group()
    mutuallyexclusive.add_argument("-j", "--jsonsummary",
                                   action="store_true",
                                   help="output JSON summary to stderr.")
    mutuallyexclusive.add_argument("-p", "--plainsummary",
                                   action="store_true",
                                   help="output plain text summary to stderr.")
    mutuallyexclusive.add_argument("-s", "--summary",
                                   action="store_true",
                                   help="output colored plain text summary to stderr. "
                                   "If stderr is not a TTY output is identical to --plainsummary.")
    cmdline.add_argument("filenames",
                         nargs="*",
                         metavar="file",
                         default=["-"], # Read from stdin if no file is specified
                         help="the YAML files to fix. Use `-` to read from `stdin`.")
    if cmdline.prog == "__main__.py":
        cmdline.prog = "yamlfixer"
    arguments = cmdline.parse_args()
    if arguments.listfixes:
        return YAMLFixer(arguments).listfixes()
    return YAMLFixer(arguments).fix()

if __name__ == '__main__':
    sys.exit(run())

==> yamlfixer_opt_nc-0.4.1-py3-none-any.whl: yamlfixer/__main__.py <==

# -*- coding: utf-8 -*-
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#

"""Execute yamlfixer from the command line."""

import sys
import argparse

from . import __version__, __copyright__
from .constants import EXIT_CMDLINEERROR
from .yamlfixer import YAMLFixer

GPLBLURB = """
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

def run():
    """Main function."""
    # Ensure we read from stdin in case it's redirected
    if ("-" not in sys.argv[1:]) and not sys.stdin.isatty():
        sys.argv.append("-")

    # Parse the command line arguments
    cmdline = argparse.ArgumentParser(description="Fix formatting problems in YAML documents. "
                                      "If no file is specified, then reads input from `stdin`.",
                                      epilog=f"{__copyright__}\n{GPLBLURB}",
                                      formatter_class=argparse.RawDescriptionHelpFormatter)
    cmdline.add_argument("-v", "--version",
                         action="version",
                         version=f"yamlfixer v{__version__}",
                         help="display this program's version number and exit.")
    cmdline.add_argument("-b", "--backup",
                         action="store_true",
                         help="make a backup copy of original files.")
    cmdline.add_argument("-B", "--backupsuffix",
                         default=".orig",
                         help="sets the suffix for backup files, `%(default)s` is the default.")
    cmdline.add_argument("-d", "--debug",
                         action="store_true",
                         help="output debug information to stderr.")
    cmdline.add_argument("-l", "--listfixes",
                         action="store_true",
                         help="output the list of available fixes.")
    mutuallyexclusive = cmdline.add_mutually_exclusive_group()
    mutuallyexclusive.add_argument("-j", "--jsonsummary",
                                   action="store_true",
                                   help="output JSON summary to stderr.")
    mutuallyexclusive.add_argument("-p", "--plainsummary",
                                   action="store_true",
                                   help="output plain text summary to stderr.")
    mutuallyexclusive.add_argument("-s", "--summary",
                                   action="store_true",
                                   help="output colored plain text summary to stderr. "
                                   "If stderr is not a TTY output is identical to --plainsummary.")
    cmdline.add_argument("filenames",
                         nargs="*",
                         metavar="file",
                         default=["-"], # Read from stdin if no file is specified
                         help="the YAML files to fix. Use `-` to read from `stdin`.")
    if cmdline.prog == "__main__.py":
        cmdline.prog = "yamlfixer"
    arguments = cmdline.parse_args()
    if arguments.backupsuffix and not arguments.backup:
        sys.stderr.write("ERROR: Option -B|--backupsuffix requires -b|--backup\n")
        return EXIT_CMDLINEERROR
    if arguments.listfixes:
        return YAMLFixer(arguments).listfixes()
    return YAMLFixer(arguments).fix()

if __name__ == '__main__':
    sys.exit(run())
